A registration mechanism for other packages to provide linters, either for custom tags or to implement their own linting styles.
register_linters(..., linters = list(...), .overwrite = FALSE)TRUE, invisibly.
Linters to register, with parameter names used to identify the associated tag.
Optionally, provide a named list of linters directly.
Whether existing linters should be overwritten. Intended to be used sparingly. For example, this could be used to implement an entire new style guide without inheriting defaults.